/***************************************************************************//**
 *   @file   AD5415.h
 *   @brief  Header file of AD5415 Driver.
 *   @author Dan Nechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 633
*******************************************************************************/

#ifndef _AD5415_H_
#define _AD5415_H_

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "Communication.h"

/*****************************************************************************/
/* GPIO                                                                      */
/*****************************************************************************/
#define AD5415_LDAC_OUT   GPIO1_PIN_OUT           
#define AD5415_LDAC_LOW   GPIO1_PIN_LOW
#define AD5415_LDAC_HIGH  GPIO1_PIN_HIGH
#define AD5415_CLR_OUT    GPIO2_PIN_OUT           
#define AD5415_CLR_LOW    GPIO2_PIN_LOW
#define AD5415_CLR_HIGH   GPIO2_PIN_HIGH

/******************************************************************************/
/* AD5415                                                                    */
/******************************************************************************/
/* Input Shift Register */
#define AD5415_CTRL_BITS(x)       (((unsigned short)(x) & 0xF) << 12)
#define AD5415_DATA_BITS(x)       ((unsigned short)(x) & 0xFFF)

/* Input Shift Register: AD5415_CTRL_BITS(x)*/
#define AD5415_CTRL_NOP               0  // No operation (power-on default).
#define AD5415_CTRL_A_LOAD_UPDATE     1  // Load and update.
#define AD5415_CTRL_A_READBACK        2  // Initiate readback.
#define AD5415_CTRL_A_LOAD_INPUT_REG  3  // Load input register.
#define AD5415_CTRL_B_LOAD_UPDATE     4  // Load and update.
#define AD5415_CTRL_B_READBACK        5  // Initiate readback.
#define AD5415_CTRL_B_LOAD_INPUT_REG  6  // Load input register.
#define AD5415_CTRL_AB_UPDATE         7  // Update DAC outputs.
#define AD5415_CTRL_AB_LOAD_INPUT_REG 8  // Load input registers.
#define AD5415_CTRL_DISBL_DAISY       9  // Disable daisy-chain.
#define AD5415_CTRL_CLK_POS_EDGE      10 // Clock data to shift register on 
                                         // rising edge.
#define AD5415_CTRL_CLR_DAC_ZERO      11 // Clear DAC output to zero scale.
#define AD5415_CTRL_CLR_DAC_MIDDLE    12 // Clear DAC output to midscale.
#define AD5415_CTRL_CONTROL_WORD      13 // Control word.

/* Control Register bits */
#define AD5415_SDO1                 (1 << 11) // Weak SDO driver.
#define AD5415_SDO2                 (1 << 10) // SDO configured as open drain.
#define AD5415_DSY                  (1 <<  9) // Enables daisy-chain mode.
#define AD5415_HCLR                 (1 <<  8) // Clears DAC output to midscale.
#define AD5415_SCLK                 (1 <<  7) // Clock on rising edge.

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/

/* Initializes communication. */
unsigned char AD5415_Init(void);

/* Sends a 16-bit value to the Input Shift Register of the device.  */
void AD5415_SetRegisterValue(unsigned short command, unsigned short dataWord);

/* Reads 12-bit data form DAC register A or DAC register B. */
unsigned short AD5415_GetRegisterValue(unsigned char dacChannel);
/* Enables specific options available for the device. */
void AD5415_Setup(unsigned short setupWord);

#endif //_AD5415_H
